pub struct BoxedMontyParams(Arc<MontyParams<BoxedUint>>);Expand description
Parameters to efficiently go to/from the Montgomery form for an odd modulus whose size and value are both chosen at runtime.
Tuple Fields
0: Arc<MontyParams<BoxedUint>>Implementations
Sourceimpl BoxedMontyParams
impl BoxedMontyParams
Sourcepub fn new(modulus: Odd<BoxedUint>) -> Self
pub fn new(modulus: Odd<BoxedUint>) -> Self
Instantiates a new set of BoxedMontyParams representing the given modulus.
TODO(tarcieri): DRY out with MontyParams::new?
Sourcepub fn new_vartime(modulus: Odd<BoxedUint>) -> Self
pub fn new_vartime(modulus: Odd<BoxedUint>) -> Self
Instantiates a new set of BoxedMontyParams representing the given modulus.
This version operates in variable-time with respect to the modulus.
TODO(tarcieri): DRY out with MontyParams::new_vartime?
Sourcepub fn bits_precision(&self) -> u32
pub fn bits_precision(&self) -> u32
Bits of precision in the modulus.
pub(crate) fn r2(&self) -> &BoxedUint
pub(crate) fn one(&self) -> &BoxedUint
pub(crate) fn mod_inv(&self) -> U64
pub(crate) fn mod_neg_inv(&self) -> Limb
pub(crate) fn mod_leading_zeros(&self) -> u32
Sourceimpl BoxedMontyParams
impl BoxedMontyParams
Sourcefn inverter(&self) -> BoxedSafeGcdInverter
fn inverter(&self) -> BoxedSafeGcdInverter
Compute the inverter for these params.